# SPDX-FileCopyrightText: 2024 Bujus_Krachus
#
# SPDX-License-Identifier: GPL-3.0-or-later

import bpy


def get_language():
    """Get the current localization translation, defaults to english"""
    # Language will only update when the script is loaded, so no change at runtime possible.
    current_language = bpy.app.translations.locale
    translations = get_translation()
    return translations.get(current_language, translations["en_US"])


def translate(language_translations, searchstring):
    """A safer way to access translations, as each string has en_US fallback"""
    try:
        return language_translations[searchstring]
    except KeyError:
        try:
            print(f"Web3D: It seems like {searchstring} is not yet translated for your language. Please create a bug report")
            return get_translation()["en_US"][searchstring]
        except Exception as e:
            print(f"Web3D: An error occurred whilst translating: {e}, please create a bug report")
            return searchstring


def get_translation():
    """Define the translation dictionary for various languages."""
    ################################################# IMPORTANT ########################################################
    # Remember when changing the english value to also either update or remove corresponding entry from the other languages.
    # Otherwise, we will get inconsistencies across the languages (and we don't want that, do we?)
    # Whilst translation is optimal, deletion is fine as well, then english will get used as fallback.
    ################################################# IMPORTANT ########################################################
    return {
        "en_US": {
            "import": "Import X3D/VRML2",
            "export": "Export X3D",
            "file_unit": "File Unit",
            "file_unit_description": "Unit used in the input file",
            "meter": "Meter",
            "meter_description": "Meter is the default unit of VRML (WRL) and X3D files. Most programs assume the objects to be defined in meters as per specification.",
            "decimeter": "Decimeter",
            "decimeter_description": "",
            "centimeter": "Centimeter",
            "centimeter_description": "",
            "milimeter": "Millimeter",
            "milimeter_description": "",
            "inch": "Inch",
            "inch_description": "",
            "custom": "CUSTOM",
            "custom_description": "Use the scale factor provided below",
            "scale": "Scale",
            "scale_description": "Scale value used when 'File Unit' is set to 'CUSTOM'",
            "selection_only": "Selection Only",
            "selection_only_description": "Export only selected objects",
            "visible_only": "Visible Only",
            "visible_only_description": "Export only visible objects",
            "active_collection_only": "Active Collection Only",
            "active_collection_only_description": "Export only objects from the active collection",
            "apply_modifiers": "Apply Modifiers",
            "apply_modifiers_description": "Use transformed mesh data from each object",
            "triangulate": "Triangulate",
            "triangulate_description": "Write quads into 'IndexedTriangleSet'",
            "normals": "Normals",
            "normals_description": "Write normals with geometry",
            "compress": "Compress",
            "compress_description": "Compress the exported file",
            "hierarchy": "Hierarchy",
            "hierarchy_description": "Export parent child relationships",
            "name_decorations": "Name decorations",
            "name_decorations_description": "Add prefixes to the names of exported nodes to indicate their type",
            "h3d_extensions": "H3D Extensions",
            "h3d_extensions_description": "Export shaders for H3D" +
                    ".\nWARNING: This feature is disabled for blender versions higher than 2.79 "
                    "as the needed API method for exporting shaders got removed from blender. "
                    "\nThis feature may get fixed eventually, but no support expected",
            "as_collection": "Import as collection",
            "as_collection_description": "Import the file as a new collection inside the active collection",
            "solidify": "Solidify",
            "solidify_description": "Solidify objects by adding a solify modifier to each of the objects",
            "solidify_value": "Solidify Value",
            "solidify_value_description": "Value used as width for the solidify modifier"
        },
        "de_DE": {
            "import": "Importiere X3D/VRML2",
            "export": "Exportiere X3D",
            "file_unit": "Dateieinheit",
            "file_unit_description": "In der Eingabedatei verwendete Einheit",
            "meter": "Meter",
            "meter_description": "Meter ist die Standardeinheit für VRML (WRL) und X3D-Dateien. Die meisten Programme gehen davon aus, dass die Objekte in Metern definiert sind.",
            "decimeter": "Dezimeter",
            "decimeter_description": "",
            "centimeter": "Zentimeter",
            "centimeter_description": "",
            "milimeter": "Millimeter",
            "milimeter_description": "",
            "inch": "Zoll",
            "inch_description": "",
            "custom": "BENUTZERDEFINIERT",
            "custom_description": "Verwendet den unten stehenden Skalierungs-Faktor",
            "scale": "Skalierung",
            "scale_description": "Skalierungswert, der verwendet wird, wenn 'Dateieinheit' auf 'BENUTZERDEFINIERT' gesetzt ist",
            "selection_only": "Nur Auswahl",
            "selection_only_description": "Nur ausgewählte Objekte exportieren",
            "visible_only": "Nur sichtbar",
            "visible_only_description": "Nur sichtbare Objekte exportieren",
            "active_collection_only": "Nur aktive Sammlung",
            "active_collection_only_description": "Nur Objekte aus der aktiven Sammlung exportieren",
            "apply_modifiers": "Modifier anwenden",
            "apply_modifiers_description": "Transformierte Mesh-Daten von jedem Objekt verwenden",
            "triangulate": "Triangulieren",
            "triangulate_description": "Quads in 'IndexedTriangleSet' schreiben",
            "normals": "Normalen",
            "normals_description": "Normalen mit Geometrie schreiben",
            "compress": "Komprimieren",
            "compress_description": "Die exportierte Datei komprimieren",
            "hierarchy": "Hierarchie",
            "hierarchy_description": "Eltern-Kind-Beziehungen exportieren",
            "name_decorations": "Namenszusätze",
            "name_decorations_description": "Präfixe zu den Namen der exportierten Knoten hinzufügen, um ihren Typ anzuzeigen",
            "h3d_extensions": "H3D Erweiterungen",
            "h3d_extensions_description": "Shader für H3D exportieren" +
                    ".\nWARNUNG: Diese Funktion ist für Blender-Versionen höher als 2.79 deaktiviert, " +
                    "da die benötigte API-Methode für den Export von Shadern aus Blender entfernt wurde. " +
                    "\nDiese Funktion könnte möglicherweise behoben werden, aber es wird keine Unterstützung erwartet",
            "as_collection": "Als Sammlung importieren",
            "as_collection_description": "Importieren Sie die Datei als neue Sammlung innerhalb der aktiven Sammlung",
            "solidify": "Verfestigen",
            "solidify_description": "Objekte verfestigen, indem jedem Objekt ein Verfestigungsmodifikator hinzugefügt wird",
            "solidify_value": "Verfestigungswert",
            "solidify_value_description": "Wert, der als Breite für den Verfestigungsmodifikator verwendet wird"
        },
        "fr_FR": {
            "import": "Importer X3D/VRML2",
            "export": "Exporter X3D",
            "file_unit": "Unité de fichier",
            "file_unit_description": "Unité utilisée dans le fichier d'entrée",
            "meter": "Mètre",
            "meter_description": "Le mètre est l'unité par défaut des fichiers VRML (WRL) et X3D. La plupart des programmes supposent que les objets sont définis en mètres conformément aux spécifications.",
            "decimeter": "Décimètre",
            "decimeter_description": "",
            "centimeter": "Centimètre",
            "centimeter_description": "",
            "milimeter": "Millimètre",
            "milimeter_description": "",
            "inch": "Pouce",
            "inch_description": "",
            "custom": "PERSONNALISÉ",
            "custom_description": "Utiliser le facteur d'échelle fourni ci-dessous",
            "scale": "Échelle",
            "scale_description": "Valeur de l'échelle utilisée lorsque 'Unité de fichier' est définie sur 'PERSONNALISÉ'",
            "selection_only": "Sélection uniquement",
            "selection_only_description": "Exporter uniquement les objets sélectionnés",
            "visible_only": "Visible seulement",
            "visible_only_description": "Exporter uniquement les objets visibles",
            "active_collection_only": "Collection active seulement",
            "active_collection_only_description": "Exporter uniquement les objets de la collection active",
            "apply_modifiers": "Appliquer les modificateurs",
            "apply_modifiers_description": "Utiliser les données de maillage transformées de chaque objet",
            "triangulate": "Trianguler",
            "triangulate_description": "Convertir les quadrilatères en 'IndexedTriangleSet'",
            "normals": "Normales",
            "normals_description": "Écrire les normales avec la géométrie",
            "compress": "Compresser",
            "compress_description": "Compresser le fichier exporté",
            "hierarchy": "Hiérarchie",
            "hierarchy_description": "Exporter les relations parent-enfant",
            "name_decorations": "Décorations de nom",
            "name_decorations_description": "Ajouter des préfixes aux noms des nœuds exportés pour indiquer leur type",
            "h3d_extensions": "Extensions H3D",
            "h3d_extensions_description": "Exporter les shaders pour H3D" +
                                          ".\nAVERTISSEMENT : Cette fonctionnalité est désactivée pour les versions de blender supérieures à 2.79 " +
                                          "car la méthode API nécessaire pour exporter les shaders a été supprimée de blender. " +
                                          "\nCette fonctionnalité pourrait être corrigée éventuellement, mais aucun support n'est attendu",
            "as_collection": "Importer en tant que collection",
            "as_collection_description": "Importer le fichier en tant que nouvelle collection dans la collection active",
            "solidify": "Solidifier",
            "solidify_description": "Solidifier les objets en ajoutant un modificateur de solidité à chacun des objets",
            "solidify_value": "Valeur de solidité",
            "solidify_value_description": "Valeur utilisée comme largeur pour le modificateur de solidité"
        },
        "es_ES": {
            "import": "Importar X3D/VRML2",
            "export": "Exportar X3D",
            "file_unit": "Unidad de archivo",
            "file_unit_description": "Unidad utilizada en el archivo de entrada",
            "meter": "Metro",
            "meter_description": "El metro es la unidad predeterminada de los archivos VRML (WRL) y X3D. La mayoría de los programas asumen que los objetos están definidos en metros según las especificaciones.",
            "decimeter": "Decímetro",
            "decimeter_description": "",
            "centimeter": "Centímetro",
            "centimeter_description": "",
            "milimeter": "Milímetro",
            "milimeter_description": "",
            "inch": "Pulgada",
            "inch_description": "",
            "custom": "PERSONALIZADO",
            "custom_description": "Usar el factor de escala proporcionado a continuación",
            "scale": "Escala",
            "scale_description": "Valor de la escala usado cuando 'Unidad de archivo' está configurada en 'PERSONALIZADO'",
            "selection_only": "Solo selección",
            "selection_only_description": "Exportar solo los objetos seleccionados",
            "visible_only": "Solo visible",
            "visible_only_description": "Exportar solo objetos visibles",
            "active_collection_only": "Solo colección activa",
            "active_collection_only_description": "Exportar solo objetos de la colección activa",
            "apply_modifiers": "Aplicar modificadores",
            "apply_modifiers_description": "Usar los datos de malla transformados de cada objeto",
            "triangulate": "Triangular",
            "triangulate_description": "Escribir los cuadriláteros en 'IndexedTriangleSet'",
            "normals": "Normales",
            "normals_description": "Escribir las normales con la geometría",
            "compress": "Comprimir",
            "compress_description": "Comprimir el archivo exportado",
            "hierarchy": "Jerarquía",
            "hierarchy_description": "Exportar las relaciones padre-hijo",
            "name_decorations": "Decoraciones de nombre",
            "name_decorations_description": "Agregar prefijos a los nombres de los nodos exportados para indicar su tipo",
            "h3d_extensions": "Extensiones H3D",
            "h3d_extensions_description": "Exportar shaders para H3D" +
                                          ".\nADVERTENCIA: Esta función está deshabilitada para versiones de blender superiores a 2.79 " +
                                          "ya que se eliminó el método API necesario para exportar shaders de blender. " +
                                          "\nEsta función podría solucionarse eventualmente, pero no se espera soporte",
            "as_collection": "Importar como colección",
            "as_collection_description": "Importar el archivo como una nueva colección dentro de la colección activa",
            "solidify": "Solidificar",
                "solidify_description": "Solidificar objetos agregando un modificador de solidificación a cada uno de los objetos",
                "solidify_value": "Valor de solidificación",
                "solidify_value_description": "Valor usado como ancho para el modificador de solidificación"
        },
        "it_IT": {
            "import": "Importa X3D/VRML2",
            "export": "Esporta X3D",
            "file_unit": "Unità di file",
            "file_unit_description": "Unità utilizzata nel file di input",
            "meter": "Metro",
            "meter_description": "Il metro è l'unità predefinita dei file VRML (WRL) e X3D. La maggior parte dei programmi presume che gli oggetti siano definiti in metri secondo le specifiche.",
            "decimeter": "Decimetro",
            "decimeter_description": "",
            "centimeter": "Centimetro",
            "centimeter_description": "",
            "milimeter": "Millimetro",
            "milimeter_description": "",
            "inch": "Pollice",
            "inch_description": "",
            "custom": "PERSONALIZZATO",
            "custom_description": "Utilizza il fattore di scala fornito qui sotto",
            "scale": "Scala",
            "scale_description": "Valore di scala utilizzato quando 'Unità di file' è impostata su 'PERSONALIZZATO'",
            "selection_only": "Solo selezione",
            "selection_only_description": "Esporta solo gli oggetti selezionati",
            "visible_only": "Solo visibile",
            "visible_only_description": "Esporta solo oggetti visibili",
            "active_collection_only": "Solo raccolta attiva",
            "active_collection_only_description": "Esporta solo oggetti dalla raccolta attiva",
            "apply_modifiers": "Applica modificatori",
            "apply_modifiers_description": "Utilizzare i dati mesh trasformati da ciascun oggetto",
            "triangulate": "Triangolare",
            "triangulate_description": "Scrivi i quadrilateri in 'IndexedTriangleSet'",
            "normals": "Normali",
            "normals_description": "Scrivi le normali con la geometria",
            "compress": "Comprimi",
            "compress_description": "Comprimi il file esportato",
            "hierarchy": "Gerarchia",
            "hierarchy_description": "Esporta le relazioni padre-figlio",
            "name_decorations": "Decorazioni di nome",
            "name_decorations_description": "Aggiungi prefissi ai nomi dei nodi esportati per indicarne il tipo",
            "h3d_extensions": "Estensioni H3D",
            "h3d_extensions_description": "Esporta shader per H3D" +
                                          ".\nAVVISO: Questa funzione è disabilitata per le versioni di blender superiori alla 2.79 " +
                                          "poiché il metodo API necessario per esportare gli shader è stato rimosso da blender. " +
                                          "\nQuesta funzione potrebbe essere risolta in futuro, ma non è previsto alcun supporto",
            "as_collection": "Importa come collezione",
            "as_collection_description": "Importa il file come una nuova collezione all'interno della collezione attiva",
            "solidify": "Solidificare",
            "solidify_description": "Solidifica gli oggetti aggiungendo un modificatore di solidità a ciascun oggetto",
            "solidify_value": "Valore di solidità",
            "solidify_value_description": "Valore usato come larghezza per il modificatore di solidità"
        },
        "ru_RU": {
            "import": "Импорт X3D/VRML2",
            "export": "Экспорт X3D",
            "file_unit": "Единица файла",
            "file_unit_description": "Единица, используемая во входном файле",
            "meter": "Метр",
            "meter_description": "Метр — это единица измерения по умолчанию для файлов VRML (WRL) и X3D. Большинство программ предполагают, что объекты определены в метрах в соответствии с спецификацией.",
            "decimeter": "Дециметр",
            "decimeter_description": "",
            "centimeter": "Сантиметр",
            "centimeter_description": "",
            "milimeter": "Миллиметр",
            "milimeter_description": "",
            "inch": "Дюйм",
            "inch_description": "",
            "custom": "ПОЛЬЗОВАТЕЛЬСКИЙ",
            "custom_description": "Использовать указанный ниже коэффициент масштабирования",
            "scale": "Масштаб",
            "scale_description": "Значение масштаба используется, когда 'Единица файла' установлена на 'ПОЛЬЗОВАТЕЛЬСКИЙ'",
            "selection_only": "Только выбор",
            "selection_only_description": "Экспортировать только выбранные объекты",
            "visible_only": "Только видимое",
            "visible_only_description": "Экспорт только видимых объектов",
            "active_collection_only": "Только активная коллекция",
            "active_collection_only_description": "Экспорт только объектов из активной коллекции",
            "apply_modifiers": "Применить модификаторы",
            "apply_modifiers_description": "Использовать преобразованные данные сетки для каждого объекта",
            "triangulate": "Триангулировать",
            "triangulate_description": "Записать квадраты в 'IndexedTriangleSet'",
            "normals": "Нормали",
            "normals_description": "Записать нормали с геометрией",
            "compress": "Сжать",
            "compress_description": "Сжать экспортированный файл",
            "hierarchy": "Иерархия",
            "hierarchy_description": "Экспортировать отношения родитель-ребенок",
            "name_decorations": "Именные префиксы",
            "name_decorations_description": "Добавить префиксы к именам экспортируемых узлов для указания их типа",
            "h3d_extensions": "Расширения H3D",
            "h3d_extensions_description": "Экспорт шейдеров для H3D" +
                                          ".\nПРЕДУПРЕЖДЕНИЕ: Эта функция отключена для версий Blender выше 2.79, " +
                                          "поскольку необходимый метод API для экспорта шейдеров был удален из Blender. " +
                                          "\nЭта функция может быть исправлена в будущем, но поддержки не ожидается",
            "as_collection": "Импортировать как коллекцию",
            "as_collection_description": "Импортировать файл как новую коллекцию внутри активной коллекции",
            "solidify": "Упрочнить",
                "solidify_description": "Укрепляет объекты, добавляя к каждому объекту модификатор упрочнения",
                "solidify_value": "Значение упрочнения",
                "solidify_value_description": "Значение, используемое в качестве ширины для модификатора упрочнения"
        },
        "zh_HANS": {
            "import": "导入 X3D/VRML2",
            "export": "导出 X3D",
            "file_unit": "文件单位",
            "file_unit_description": "输入文件中使用的单位",
            "meter": "米",
            "meter_description": "米是 VRML (WRL) 和 X3D 文件的默认单位。大多数程序假设对象按规范以米为单位定义。",
            "decimeter": "分米",
            "decimeter_description": "",
            "centimeter": "厘米",
            "centimeter_description": "",
            "milimeter": "毫米",
            "milimeter_description": "",
            "inch": "英寸",
            "inch_description": "",
            "custom": "自定义",
            "custom_description": "使用下方提供的比例因子",
            "scale": "比例",
            "scale_description": "当 '文件单位' 设置为 '自定义' 时使用的比例值",
            "selection_only": "仅选择",
            "selection_only_description": "仅导出选定的对象",
            "visible_only": "仅可见",
            "visible_only_description": "仅导出可见对象",
            "active_collection_only": "仅活动集合",
            "active_collection_only_description": "仅导出活动集合中的对象",
            "apply_modifiers": "应用修改器",
            "apply_modifiers_description": "使用每个对象的变换网格数据",
            "triangulate": "三角化",
            "triangulate_description": "将四边形写入 'IndexedTriangleSet'",
            "normals": "法线",
            "normals_description": "将法线与几何体一起写入",
            "compress": "压缩",
            "compress_description": "压缩导出的文件",
            "hierarchy": "层次结构",
            "hierarchy_description": "导出父子关系",
            "name_decorations": "名称装饰",
            "name_decorations_description": "在导出的节点名称中添加前缀以指示其类型",
            "h3d_extensions": "H3D 扩展",
            "h3d_extensions_description": "为 H3D 导出着色器" +
                                          "。\n警告：对于高于 Blender 2.79 的版本，此功能已禁用，" +
                                          "因为导出着色器所需的 API 方法已从 Blender 中删除。" +
                                          "\n此功能可能会在将来修复，但不提供支持",
            "as_collection": "作为集合导入",
            "as_collection_description": "将文件作为一个新的集合导入到活动集合中",
            "solidify": "实体化",
            "solidify_description": "通过为每个对象添加实体化修改器来使对象实体化",
            "solidify_value": "实体化值",
            "solidify_value_description": "用作实体化修改器宽度的值",
        },
        "ja_JP": {
            "import": "インポート X3D/VRML2",
            "export": "エクスポート X3D",
            "file_unit": "ファイル単位",
            "file_unit_description": "入力ファイルで使用される単位",
            "meter": "メートル",
            "meter_description": "メートルは VRML (WRL) および X3D ファイルのデフォルト単位です。ほとんどのプログラムは、オブジェクトが仕様に従ってメートルで定義されていると仮定します。",
            "decimeter": "デシメートル",
            "decimeter_description": "",
            "centimeter": "センチメートル",
            "centimeter_description": "",
            "milimeter": "ミリメートル",
            "milimeter_description": "",
            "inch": "インチ",
            "inch_description": "",
            "custom": "カスタム",
            "custom_description": "以下で提供されているスケール係数を使用",
            "scale": "スケール",
            "scale_description": "'ファイル単位' が 'カスタム' に設定されている場合に使用されるスケール値",
            "selection_only": "選択のみ",
            "selection_only_description": "選択されたオブジェクトのみをエクスポート",
            "visible_only": "表示中のみ",
            "visible_only_description": "表示中のオブジェクトのみをエクスポート",
            "active_collection_only": "アクティブコレクションのみ",
            "active_collection_only_description": "アクティブなコレクション内のオブジェクトのみをエクスポート",
            "apply_modifiers": "モディファイアを適用",
            "apply_modifiers_description": "各オブジェクトの変換されたメッシュデータを使用",
            "triangulate": "三角形化",
            "triangulate_description": "四角形を 'IndexedTriangleSet' に書き込む",
            "normals": "法線",
            "normals_description": "ジオメトリに法線を書き込む",
            "compress": "圧縮",
            "compress_description": "エクスポートされたファイルを圧縮",
            "hierarchy": "階層構造",
            "hierarchy_description": "親子関係をエクスポート",
            "name_decorations": "名前装飾",
            "name_decorations_description": "エクスポートされたノードの名前にプレフィックスを追加してタイプを示す",
            "h3d_extensions": "H3D 拡張機能",
            "h3d_extensions_description": "H3D のシェーダーをエクスポート" +
                                          ".\n警告：この機能は Blender 2.79 より上のバージョンでは無効になっています。" +
                                          "シェーダーをエクスポートするために必要な API メソッドが Blender から削除されたためです。" +
                                          "\nこの機能は将来的に修正される可能性がありますが、サポートは期待されていません。",
            "as_collection": "コレクションとしてインポート",
            "as_collection_description": "ファイルをアクティブなコレクション内に新しいコレクションとしてインポートします",
            "solidify": "ソリディファイ",
            "solidify_description": "各オブジェクトにソリディファイモディファイアを追加してオブジェクトをソリディファイする",
            "solidify_value": "ソリディファイ値",
            "solidify_value_description": "ソリディファイモディファイアの幅として使用する値"
        },
        "hi_IN": {
            "import": "आयात X3D/VRML2",
            "export": "निर्यात X3D",
            "file_unit": "फ़ाइल इकाई",
            "file_unit_description": "इनपुट फ़ाइल में उपयोग की गई इकाई",
            "meter": "मीटर",
            "meter_description": "मीटर VRML (WRL) और X3D फ़ाइलों की डिफ़ॉल्ट इकाई है। अधिकांश प्रोग्राम मानते हैं कि वस्तुओं को निर्दिष्ट अनुसार मीटर में परिभाषित किया गया है।",
            "decimeter": "डेसीमीटर",
            "decimeter_description": "",
            "centimeter": "सेंटीमीटर",
            "centimeter_description": "",
            "milimeter": "मिलीमीटर",
            "milimeter_description": "",
            "inch": "इंच",
            "inch_description": "",
            "custom": "कस्टम",
            "custom_description": "नीचे दिए गए पैमाने का कारक उपयोग करें",
            "scale": "स्केल",
            "scale_description": "'फ़ाइल इकाई' को 'कस्टम' पर सेट किए जाने पर उपयोग किया गया स्केल मान",
            "selection_only": "केवल चयन",
            "selection_only_description": "केवल चयनित वस्तुओं को निर्यात करें",
            "visible_only": "केवल दृश्य",
            "visible_only_description": "केवल दृश्यमान वस्तुएँ निर्यात करें",
            "active_collection_only": "केवल सक्रिय संग्रह",
            "active_collection_only_description": "केवल सक्रिय संग्रह की वस्तुओं को निर्यात करें",
            "apply_modifiers": "मॉडिफ़ायर लागू करें",
            "apply_modifiers_description": "प्रत्येक वस्तु से रूपांतरित मेश डेटा का उपयोग करें",
            "triangulate": "त्रिकोणित करें",
            "triangulate_description": "'IndexedTriangleSet' में चतुर्भुज लिखें",
            "normals": "नॉर्मल",
            "normals_description": "ज्यामिति के साथ नॉर्मल लिखें",
            "compress": "संकुचित करें",
            "compress_description": "निर्यात की गई फ़ाइल को संपीड़ित करें",
            "hierarchy": "अनुक्रम",
            "hierarchy_description": "मूल्य और बाल संबंध निर्यात करें",
            "name_decorations": "नाम सजावट",
            "name_decorations_description": "निर्यात किए गए नोड्स के नामों में उनके प्रकार को इंगित करने के लिए उपसर्ग जोड़ें",
            "h3d_extensions": "H3D एक्सटेंशन",
            "h3d_extensions_description": "H3D के लिए शेडर्स निर्यात करें" +
                                          ".\nचेतावनी: यह सुविधा Blender संस्करण 2.79 से अधिक के लिए अक्षम है, " +
                                          "क्योंकि शेडर्स के निर्यात के लिए आवश्यक API विधि Blender से हटा दी गई है।" +
                                          "\nयह सुविधा भविष्य में ठीक हो सकती है, लेकिन कोई समर्थन अपेक्षित नहीं है",
            "as_collection": "संग्रह के रूप में आयात करें",
            "as_collection_description": "सक्रिय संग्रह के भीतर फ़ाइल को एक नए संग्रह के रूप में आयात करें",
            "solidify": "ठोस बनाएं",
                "solidify_description": "प्रत्येक वस्तु में ठोस संशोधक जोड़कर वस्तुओं को ठोस बनाएं",
                "solidify_value": "ठोस मान",
                "solidify_value_description": "ठोस संशोधक की चौड़ाई के रूप में प्रयुक्त मान"
        },
        "ar_AR": {
            "import": "استيراد X3D/VRML2",
            "export": "تصدير X3D",
            "file_unit": "وحدة الملف",
            "file_unit_description": "الوحدة المستخدمة في ملف الإدخال",
            "meter": "متر",
            "meter_description": "المتر هو الوحدة الافتراضية لملفات VRML (WRL) و X3D. تفترض معظم البرامج أن الأشياء محددة بالأمتار حسب المواصفات.",
            "decimeter": "ديسيمتر",
            "decimeter_description": "",
            "centimeter": "سنتيمتر",
            "centimeter_description": "",
            "milimeter": "ميليمتر",
            "milimeter_description": "",
            "inch": "بوصة",
            "inch_description": "",
            "custom": "مخصص",
            "custom_description": "استخدم عامل المقياس المحدد أدناه",
            "scale": "المقياس",
            "scale_description": "قيمة المقياس المستخدمة عند تعيين 'وحدة الملف' إلى 'مخصص'",
            "selection_only": "التحديد فقط",
            "selection_only_description": "تصدير الكائنات المحددة فقط",
            "visible_only": "مرئي فقط",
            "visible_only_description": "تصدير الكائنات المرئية فقط",
            "active_collection_only": "مجموعة نشطة فقط",
            "active_collection_only_description": "تصدير الكائنات من المجموعة النشطة فقط",
            "apply_modifiers": "تطبيق المعدلات",
            "apply_modifiers_description": "استخدام بيانات الشبكة المحولة من كل كائن",
            "triangulate": "مثلثي",
            "triangulate_description": "كتابة المربعات في 'IndexedTriangleSet'",
            "normals": "النورمالز",
            "normals_description": "كتابة النورمالز مع الهندسة",
            "compress": "ضغط",
            "compress_description": "ضغط الملف المُصدّر",
            "hierarchy": "التسلسل الهرمي",
            "hierarchy_description": "تصدير علاقات الأب-الابن",
            "name_decorations": "زخرفة الأسماء",
            "name_decorations_description": "إضافة بادئات إلى أسماء العقد المصدرة للإشارة إلى نوعها",
            "h3d_extensions": "امتدادات H3D",
            "h3d_extensions_description": "تصدير شيدر لـ H3D" +
                                          ".\nتحذير: هذه الميزة معطلة للإصدارات من Blender التي تتجاوز 2.79 " +
                                          "نظرًا لإزالة الطريقة المطلوبة من واجهة برمجة التطبيقات لتصدير الشيدرز من Blender." +
                                          "\nقد يتم إصلاح هذه الميزة في المستقبل، ولكن لا يُتوقع دعمها",
            "as_collection": "استيراد كـ مجموعة",
            "as_collection_description": "استيراد الملف كمجموعة جديدة داخل المجموعة النشطة",
            "solidify": "تصلب",
                "solidify_description": "تصلب الكائنات عن طريق إضافة معدل تصلب لكل كائن",
                "solidify_value": "قيمة التصلب",
                "solidify_value_description": "القيمة المستخدمة كعرض لمعدل التصلب"
        }
    }
